@@ -27,6 +27,7 @@
 #include <FL/Fl_Double_Window.H>
 #include <FL/Fl_Browser.H>
 #include <FL/Fl_Pack.H>
+#include <FL/Fl_Menu_Bar.H>
 #include <string>
 
 #include "combo.h"
@@ -70,6 +71,11 @@ extern Fl_Double_Window *dxcc_window;
 extern Fl_Double_Window	*dxcluster_viewer;
 extern Fl_Double_Window *rxaudio_dialog;
 
+extern Fl_Menu_Item 	menu_[];
+extern int 				main_menu_size;
+extern Fl_Group			*mnuFrame;;
+extern void change_menu_fonts( Fl_Font font, int size);
+
 extern bool first_use;
 extern bool bEXITING;
 
@@ -386,6 +392,7 @@ extern void set_scope_xaxis_2(double y2);
 extern void set_scope_yaxis_1(double x1);
 extern void set_scope_yaxis_2(double x2);
 extern void set_scope_clear_axis();
+extern void set_scope_colors();
 
 extern void set_CWwpm();
 extern void put_rx_char(unsigned int data, int style = FTextBase::RECV);
